#!/bin/bash

###############################################################################
# Nom : classement.sh
#
# Creation : 20120610
# Auteur : Sebastien Le Lourec
#
# Description :
# Trie photos et videos du repertoire courant et les classe dans le dossier
# personnel correspondant dans des sous-dossiers chronologiques (annee/mois)
#
# Licence :
# Ce code est distribué sous licence CeCILL.
# Version française : http://www.cecill.info/licences/Licence_CeCILL_V1-fr.txt
# English version : http://www.cecill.info/licences/Licence_CeCILL_V1.1-US.txt
#
# Version : 0.1.004
# Modification : 20121122
###############################################################################

### Variables ###
# Listings
export FICLIST=./fichiers.lis
export VIDLIST=./videos.lis
export PHOLIST=./photos.lis

# Repertoires
export VIDEOS=$HOME/Vidéos
export PHOTOS=$HOME/Images
export VIDEST=$VIDEOS/$1
export PHODEST=$PHOTOS/$1


### Fonctions ###
usage()
{
    echo "1 argument necessaire"
    echo "Indiquer le nom du sous-repertoire de destination"
    echo "Indiquez ? pour plus d'informations"
}

aide()
{
    echo "Description :"
    echo "Trie photos et videos du repertoire courant et les classe dans le dossier"
    echo "personnel correspondant dans des sous-dossiers chronologiques (annee/mois)"
    echo "Ex. 1 : /home/vous/Images/repertoire-en-parametre/201206/"
    echo "Ex. 2 : /home/vous/Vidéos/repertoire-en-parametre/201206/"
}


### Programme ###

# Test du nombre d'arguments
if [ $# -eq 0 ];
    then
        usage
        exit 1
fi

# Test de l'argument
if [ $1 == "?" ]
    then
        aide
        exit 1
fi

# Test de présence des listings de photos/videos et suppression
if [ -f $PHOLIST ];
    then
        rm -f $PHOLIST
elif [ -f $VIDLIST ];
    then
        rm -f $VIDLIST
fi

# Liste de tous fichiers
ls | egrep -ve "sh|lis" > $FICLIST

# Bidouille pour garder les espaces dans les noms de fichiers
old_IFS=$IFS
IFS=$'\n'

# Tri des photos et des videos
for fic in `cat $FICLIST`;
    do file $fic | grep -i image
       if [ $? == "0" ];
       then echo $fic >> $PHOLIST
       else echo $fic >> $VIDLIST
       fi
    done

# Test de presence des dossiers de destination des photos
# creation eventuelle et deplacement
for pho in `cat $PHOLIST`;
    do
        MDATE=`stat $pho | tr -d "[:space:]" | cut -d":" -f 15 | awk -F"-" {'print $1$2'}`
        if [ -x $PHODEST/$MDATE ];
            then
                echo "$pho : Dossier $PHODEST/$MDATE  present"
                mv "$pho" $PHODEST/$MDATE/
            else
                echo "$pho : Dossier $PHODEST/$MDATE absent"
                mkdir -p $PHODEST/$MDATE
                mv "$pho" $PHODEST/$MDATE/
        fi
    done

# Test de presence des dossiers de destination des videos
# creation eventuelle et deplacement
for vid in `cat $VIDLIST`;
    do
        MDATE=`stat $vid | tr -d "[:space:]" | cut -d":" -f 15 | awk -F"-" {'print $1$2'}`
        if [ -x $VIDEST/$MDATE ];
            then
                echo "$vid : Dossier $VIDEST/$MDATE  present"
                mv "$vid" $VIDEST/$MDATE/
            else
                echo "$vid : Dossier $VIDEST/$MDATE absent"
                mkdir -p $VIDEST/$MDATE
                mv "$vid" $VIDEST/$MDATE/
        fi
    done


# Fin de la bidouille pour les espaces
IFS=$old_IFS

rm -f *lis
exit 0
